--[[

]]--
local addonName, vars = ...
local L = vars.L --- localizzazione
local ERA = _G[addonName]

--Upvalue
local CreateFrame = CreateFrame

--
--legge un valore d'appoggio settato in un frame
function ERA:GetFrameVal(frame, val)
   return frame._custom[val]   
end
--setta un valore d'appoggio in un frame
function ERA:SetFrameVal(frame, var, val)
   frame._custom = frame._custom or {}
   frame._custom[var] = val
end

function ERA:GetFrameDB(frame, val)  
	local r = ERA:DB()
	local class = ERA:GetFrameVal(frame, "class")
	local type = ERA:GetFrameVal(frame,"type") or 1
	if r[class] and r[class][type] then
		return r[class][type][val]   
	end   
end

function ERA:SetFrameDB(frame, var, val)
	local r = ERA:DB()
	local class = ERA:GetFrameVal(frame, "class")
	local type = ERA:GetFrameVal(frame,"type") or 1
	if r[class] and r[class][type] then
		r[class][type][var] = val
	end   
end

function ERA:EnableFrameDB(frame)
	local r = ERA:DB()
	local class = ERA:GetFrameVal(frame, "class")
	local type = ERA:GetFrameVal(frame,"type") or 1
	if r[class] and r[class][type] then
		r[class][type] = r[class][type] or {}
		ERA:SetFrameVal(frame, "DBEnabled", true)
	end      
end


function ERA:SaveFramePos(frame)
	if not ERA:GetFrameVal(frame, "DBEnabled") then return end
	local from, _, to, x, y = frame:GetPoint()   
	ERA:SetFrameDB(frame, "from", from)
	ERA:SetFrameDB(frame,"to", to)
	ERA:SetFrameDB(frame,"x",x)
	ERA:SetFrameDB(frame,"y", y)
   
end


function ERA:RestoreFramePos(frame)
   local from, parent, to, x, y = ERA:GetFrameDB(frame, "from"),frame:GetParent(),ERA:GetFrameDB(frame,"to"), ERA:GetFrameDB(frame,"x"), ERA:GetFrameDB(frame,"y")
   if from and parent and to and x and y then
      frame:ClearAllPoints()
      frame:SetPoint(from, parent, to, x, y)
   end   
end

function ERA:LockFrame(frame)
	ERA:SetFrameVal(frame,"lock", true)
	ERA:SetFrameDB(frame,"lock",true)
	frame.title.lock:SetTexture(ERA:GetTexture("lock"))
    frame:EnableMouse()
    frame.title.lockFrame:EnableMouse(true)
end

function ERA:UnlockFrame(frame)
	ERA:SetFrameVal(frame,"lock")
	ERA:SetFrameDB(frame,"lock")
	frame.title.lock:SetTexture(ERA:GetTexture("unlock"))
    frame:EnableMouse(true)
end

function ERA:LockUnlockFrame(frame,state)	
	if state then
		ERA:LockFrame(frame)
	else      
		ERA:UnlockFrame(frame)
	end   
end

function ERA:Frame(class,type,named)
	local name
	if named and class then name = addonName..class..(type or 1) end
	local frame = CreateFrame('Frame',name,UIParent)  
	frame:SetSize(120,200)
	frame:SetPoint("TOP",UIParent, "TOP", 0, -50)
	frame.bg = frame:CreateTexture(nil, "BACKGROUND",nil,-7)
	frame.bg:SetAllPoints()
	frame.bg:SetTexture(0,0,0,0.2)
	frame:EnableMouse(true)
	frame:SetMovable(true)
	frame:SetResizable(true)
	frame:SetClampedToScreen(true)
	frame:SetFrameStrata("HIGH")

	frame:RegisterForDrag("LeftButton")
	frame:SetScript("OnDragStart", function(self)
		 if self:IsMovable() then
			self:StartMoving()
		 end
	end)
	frame:SetScript("OnDragStop", function(self)
		 self:StopMovingOrSizing() 
		 ERA:SaveFramePos(frame)
	end)
	frame:SetScript("OnHide", function()
		 frame:StopMovingOrSizing()       
		 ERA:SaveFramePos(frame)
	end)
	
	frame.title = CreateFrame("Frame",nil,frame)
	frame.title:SetSize(1,20)
	frame.title:SetPoint("TOPRIGHT",frame,"TOPRIGHT")
	frame.title:SetPoint("TOPLEFT",frame,"TOPLEFT")
	frame.title.bg = frame.title:CreateTexture(nil,"BACKGROUND",nil,-7)
	frame.title.bg:SetAllPoints()
	frame.title.bg:SetTexture(1,1,1,0.2)	
	
	frame.title.lockFrame = CreateFrame("Frame",nil,frame.title)
	frame.title.lockFrame:SetSize(20,1)
	frame.title.lockFrame:SetPoint("TOPLEFT",frame.title,"TOPLEFT")		
	frame.title.lockFrame:SetPoint("BOTTOMLEFT",frame.title,"BOTTOMLEFT")		
	frame.title.lockFrame:EnableMouse(true)
	frame.title.lockFrame:SetScript("OnMouseUp", function(self)         
		 ERA:LockUnlockFrame(frame, not ERA:GetFrameVal(frame,"lock"))
	end)
	
	frame.title.lock = frame.title.lockFrame:CreateTexture(nil,"BACKGROUND",-6)
	frame.title.lock:SetAllPoints()
	frame.title.lock:SetTexture(ERA:GetTexture("unlock"))
		
	frame.title.txt = frame.title:CreateFontString(nil, "BACKGROUND")
	frame.title.txt:SetFontObject(GameFontNormal)
	frame.title.txt:SetTextColor(0, 1, 0)
	frame.title.txt:SetPoint("TOPRIGHT",frame.title,"TOPRIGHT")
	frame.title.txt:SetPoint("BOTTOMRIGHT",frame.title,"BOTTOMRIGHT")
	frame.title.txt:SetPoint("TOPLEFT",frame.title.lock,"TOPLEFT")

	frame.txt = frame:CreateFontString(nil, "BACKGROUND")
	frame.txt:SetFontObject(GameFontNormal)
	frame.txt:SetTextColor(1, 1, 1)
	frame.txt:SetPoint("TOPLEFT",frame.title,"BOTTOMLEFT")   
	frame.txt:SetPoint("TOPRIGHT",frame.title,"BOTTOMRIGHT")   
	frame.txt:SetWordWrap(true)

	if class then
	  ERA:SetFrameVal(frame, "class", class)
	  ERA:SetFrameVal(frame, "type",type or 1)
	end
	  
	return frame
end
